Summary: Tool for managing bootable, immutable filesystem trees
Name: ostree
Version: 2017.14
Release: 2%{?dist}
#VCS: git:https://github.com/ostreedev/ostree
# The source tarball is generated via make -C packaging dist-snapshot
# which handles git submodules.
Source0: https://github.com/ostreedev/%{name}/releases/download/v%{version}/libostree-%{version}.tar.xz
Source1: 91-ostree.preset
License: LGPLv2+
URL: https://github.com/ostreedev/ostree

# For autosetup
BuildRequires: git
# We always run autogen.sh
BuildRequires: autoconf automake libtool
# For docs
BuildRequires: gtk-doc
# Core requirements
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(libsoup-2.4)
BuildRequires: libattr-devel
# Extras
BuildRequires: pkgconfig(libarchive)
BuildRequires: pkgconfig(liblzma)
BuildRequires: pkgconfig(libselinux)
BuildRequires: pkgconfig(mount)
BuildRequires: pkgconfig(fuse)
BuildRequires: pkgconfig(e2p)
BuildRequires: libcap-devel
BuildRequires: gpgme-devel
BuildRequires: pkgconfig(libsystemd)
BuildRequires: /usr/bin/g-ir-scanner
BuildRequires: dracut
BuildRequires:  bison

# Runtime requirements
Requires: dracut
Requires: systemd-units

# this ideally should match to the glib2 version from the buildroot:
# https://bugzilla.redhat.com/show_bug.cgi?id=1371704
Requires: glib2 >= 2.50

%description
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package devel
Summary: Development headers for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The %{name}-devel package includes the header files for the %{name} library.

%ifnarch s390 s390x %{arm}
%package grub2
Summary: GRUB2 integration for OSTree
Group: Development/Libraries
%ifnarch aarch64
Requires: grub2
%else
Requires: grub2-efi
%endif
Requires: ostree

%description grub2
GRUB2 integration for OSTree
%endif

%package fuse
Summary: FUSE utilities for ostree
Requires: fuse

%description fuse
%{summary}

%prep
%autosetup -n libostree-%{version} -Sgit

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules \
	   --enable-gtk-doc \
	   --with-selinux \
	   --with-curl \
	   --with-openssl \
	   --with-dracut=yesbutnoconf
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p -c"
find $RPM_BUILD_ROOT -name '*.la' -delete
install -D -m 0644 %{SOURCE1} $RPM_BUILD_ROOT/%{_prefix}/lib/systemd/system-preset/91-ostree.preset
# Right now we aren't doing installed tests here
rm -f %{buildroot}%{_libexecdir}/libostree/ostree-trivial-httpd

%clean
rm -rf $RPM_BUILD_ROOT

%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%{!?_licensedir:%global license %%doc}
%license COPYING
%doc README.md
%{_bindir}/ostree
%{_datadir}/ostree/trusted.gpg.d
%{_sysconfdir}/ostree
%{_datadir}/bash-completion/completions/*
%dir %{_prefix}/lib/dracut/modules.d/98ostree
%{_prefix}/lib/systemd/system/ostree*.service
%{_prefix}/lib/dracut/modules.d/98ostree/*
%{_libdir}/*.so.1*
%{_libdir}/girepository-1.0/OSTree-1.0.typelib
%{_mandir}/man*/*.gz
%{_prefix}/lib/systemd/system-generators/ostree-system-generator
%{_prefix}/lib/systemd/system-preset/91-ostree.preset
%exclude %{_sysconfdir}/grub.d/*ostree
%exclude %{_libexecdir}/libostree/grub2*
%{_prefix}/lib/ostree/ostree-prepare-root
%{_prefix}/lib/ostree/ostree-remount
%{_prefix}/lib/tmpfiles.d/*
%{_libexecdir}/libostree/*

%files fuse
%{_bindir}/rofiles-fuse

%files devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/ostree
%{_datadir}/gir-1.0/OSTree-1.0.gir

%ifnarch s390 s390x %{arm}
%files grub2
%{_sysconfdir}/grub.d/*ostree
%{_libexecdir}/libostree/grub2*
%endif

%changelog
* Tue Dec 05 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.14-2
- Rebuild for 7.4

* Tue Dec 05 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.14-1
- New upstream version for 7.4.4

* Mon Sep 25 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.11-1
- New upstream version for 7.4.2

* Mon Aug 21 2017 Colin Walters <walters@redhat.com> - 2017.10-2
- Switch to libcurl
  Resolves: #1444903

* Mon Jun 19 2017 Colin Walters <walters@verbum.org> - 2017.7-1
- New upstream version for 7.4

* Tue Jun 06 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.6-3
- Add versioned runtime req on glib2 (RHBZ#1371704)

* Mon May 22 2017 Colin Walters <walters@verbum.org> - 2017.6-2
- New upstream version

* Mon May 08 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.5-2
- Rebuild for 7.4

* Mon May 01 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.5-1
- New release
  Resolves: #1447077

* Wed Apr 12 2017 Colin Walters <walters@verbum.org> - 2017.3-3
- Rebuild for 7.4

* Thu Apr 06 2017 David Marlin <dmarlin@redhat.com>
- Patch spec to get non-grub archs working again
  Resolves: #1439395

* Wed Mar 29 2017 Jonathan Lebon <jlebon@redhat.com> - 2017.3-2
- Backport fix for ovl selinux labeling
  Resolves: #1436751

* Tue Mar 21 2017 Colin Walters <walters@verbum.org> - 2017.3-1
- New upstream version
  Resolves: #1433422

* Thu Mar 09 2017 Colin Walters <walters@verbum.org> - 2017.1-4.atomic
- grub2: Add a requires on ostree

* Thu Feb 23 2017 Colin Walters <walters@redhat.com> - 2017.1-3.atomic
- Backport libmount unref patch
  Resolves: #1426280

* Tue Jan 24 2017 Colin Walters <walters@verbum.org>
- New upstream version
  Resolves: #1416089
- Drop BR/requires on libgsystem, we do not use it anymore
- Enable libmount code so we handle /boot being ro

* Mon Dec 12 2016 walters@redhat.com - 2016.15-1.atomic
- New upstream version
- Resolves: #1403933

* Thu Nov 10 2016 Jonathan Lebon <jlebon@redhat.com> - 2016.11-2.atomic
- Add ostree proxy patch (RHBZ: #1370558)

* Mon Oct 24 2016 Colin Walters <walters@redhat.com>
- New upstream version

* Thu Sep 08 2016 walters@redhat.com - 2016.10-1
- New upstream version

* Fri Jul 08 2016 walters@redhat.com - 2016.7-3.atomic
- New upstream version
- Add ostree-fuse -> fuse requirement so people can unmount the result

* Tue Apr 19 2016 Colin Walters <walters@redhat.com> - 2016.5-2.atomic
- New upstream version
- Backport patch for detected race conditions in pull
- Split off new fuse package with rofiles-fuse

* Tue Feb 09 2016 Colin Walters <walters@redhat.com> - 2016.1-2.atomic
- Backport patch to fix GTlsInteraction

* Tue Jan 12 2016 Colin Walters <walters@redhat.com> - 2016.1-1.atomic
- New upstream version
- Apply patch to fix /tmp permission regression: Resolves: #1297745

* Tue Dec 08 2015 Colin Walters <walters@redhat.com> - 2015.11-2.atomic
- New upstream version
- Continuation of: #1265756

* Wed Sep 23 2015 Colin Walters <walters@redhat.com> - 2015.9-2.atomic
- New upstream version

* Sun May 31 2015 Colin Walters <walters@redhat.com> - 2015.6-4.atomic
- Backport complete patch: Resolves: #1225088

* Fri May 29 2015 Colin Walters <walters@redhat.com> - 2015.6-3.atomic
- Backport patches from Fedora rawhide
  Ensure bootloader ordering: Resolves: #1225088
  Close sysroot FD (would affect RHEL if we respun the installer)

* Fri Apr 17 2015 Colin Walters <walters@redhat.com> - 2015.6-2.atomic
- New upstream release

* Tue Apr 07 2015 Colin Walters <walters@redhat.com> - 2015.5-2.atomic
- New upstream release

* Fri Jan 23 2015 Colin Walters <walters@redhat.com> - 2015.3-2.atomic
- New upstream release
- Disable static deltas until they are stable

* Thu Jan 08 2015 Colin Walters <walters@redhat.com> - 2015.2-1.atomic
- New upstream release

* Fri Dec 19 2014 Colin Walters <walters@redhat.com> - 2014.9-4.atomic
- Rebuild for 7.1

* Mon Oct 27 2014 Colin Walters <walters@redhat.com> - 2014.9-3.atomic
- Add patch to fix crasher on UEFI

* Fri Oct 24 2014 Colin Walters <walters@redhat.com> - 2014.9-2.atomic
- New upstream release

* Fri Oct 17 2014 Colin Walters <walters@redhat.com> - 2014.8-2.atomic
- Add patch for anaconda work

* Thu Oct 16 2014 Colin Walters <walters@redhat.com> - 2014.8-1.atomic
- New upstream source

* Fri Oct 03 2014 Colin Walters <walters@redhat.com> - 2014.7-1.atomic
- New upstream source

* Sat Sep 20 2014 Colin Walters <walters@redhat.com> - 2014.6-3.atomic
- Backport patches for /etc merging

* Mon Sep 08 2014 Colin Walters <walters@redhat.com> - 2014.6-2.atomic
- New upstream release

* Fri Jun 27 2014 Colin Walters <walters@redhat.com>
- Add patch for tls-ca-path to enable restricting to Red Hat CDN CA

* Thu Jun 26 2014 Colin Walters <walters@redhat.com>
- Add patch to hard require client certs, use it.  This ensures
  that the functionality is available in the buildroot, and we
  do not silently compile without it.

* Thu Jun 26 2014 Colin Walters <walters@redhat.com>
- Rebuild to pick up tagged libsoup for client-side certs

* Thu Jun 12 2014 Colin Walters <walters@redhat.com>
- New atomic build

* Sat Mar 22 2014 Colin Walters <walters@verbum.org> - 2014.3-1.collider.0
- New upstream release

* Sat Mar 01 2014 Colin Walters <walters@verbum.org> - 2014.2-1
- New upstream release
- Depend on libselinux
- Explicitly depend on libarchive too, we were actually failing
  to disable it before

* Fri Jan 24 2014 Colin Walters <walters@verbum.org> - 2014.1-1
- New upstream release

* Mon Jan 13 2014 Colin Walters <walters@verbum.org> - 2013.7-2
- Add preset file so ostree-remount is enabled by default, since
  it needs to be.

* Tue Oct 15 2013 Colin Walters <walters@verbum.org> - 2013.7-1
- New upstream release
- Now LGPLv2+ only
- Enable libarchive since it might be useful for people
- Enable new gpgme dependency

* Thu Sep 12 2013 Colin Walters <walters@verbum.org> - 2013.6-3
- Enable introspection

* Mon Sep 09 2013 Colin Walters <walters@verbum.org> - 2013.6-2
- Tweak description

* Mon Sep 09 2013 Colin Walters <walters@verbum.org> - 2013.6-1
- New upstream release

* Sat Aug 24 2013 Colin Walters <walters@verbum.org> - 2013.5-3
- And actually while we are here, drop all the embedded dependency
  goop from this spec file; it may live on in the EPEL branch.

* Sat Aug 24 2013 Colin Walters <walters@verbum.org> - 2013.5-2
- Drop requirement on linux-user-chroot
  We now require triggers to be processed on the build server
  by default, so ostree does not runtime-depend on linux-user-chroot.

* Sat Aug 17 2013 Colin Walters <walters@verbum.org> - 2013.5-1
- New upstream release
- Add devel package

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2013.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 16 2013 Colin Walters <walters@verbum.org> - 2013.4-1
- New upstream release

* Sun Jul 07 2013 Colin Walters <walters@verbum.org> - 2013.3-1
- New upstream release

* Mon Apr 01 2013 Colin Walters <walters@verbum.org> - 2013.1-1
- New upstream release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2012.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Dec 23 2012 Colin Walters <walters@verbum.org> - 2012.13-1
- New upstream release

* Tue Dec 18 2012 Colin Walters <walters@verbum.org> - 2012.12-2
- Explicitly enable grub2 hook; otherwise we pick up whatever
  the buildroot has, which is not what we want.

* Mon Nov 19 2012 Colin Walters <walters@verbum.org> - 2012.12-1
- Initial import; thanks to Michel Alexandre Salim for review
  https://bugzilla.redhat.com/show_bug.cgi?id=819951

